@@ -41,7 +41,7 @@ use strict;
 
     require_version DBI 1.61;
 
-    $VERSION = '9.2.0.0001';
+    $VERSION = '10.1.0.0001';
 
     bootstrap DBD::cubrid $VERSION;
 
@@ -57,25 +57,31 @@ use strict;
 
         $class .= "::dr";
 
+        DBD::cubrid::st->install_method ('cubrid_lob_get');
+        DBD::cubrid::st->install_method ('cubrid_lob_export');
+        DBD::cubrid::st->install_method ('cubrid_lob_import');
+        DBD::cubrid::st->install_method ('cubrid_lob_close');
+
         $drh = DBI::_new_drh ($class, {
                 'Name' => 'cubrid',
                 'Version' => $VERSION,
                 'Err'    => \$DBD::cubrid::err,
                 'Errstr' => \$DBD::cubrid::errstr,
                 'Attribution' => 'DBD::cubrid by Zhang Hui'
-            });
+            })
+        	or return undef;
 
-        DBD::cubrid::st->install_method ('cubrid_lob_get');
-        DBD::cubrid::st->install_method ('cubrid_lob_export');
-        DBD::cubrid::st->install_method ('cubrid_lob_import');
-        DBD::cubrid::st->install_method ('cubrid_lob_close');
+        return $drh;
+    }
 
-        $drh
+    sub CLONE {
+    	undef $drh;
     }
 }
 
 {   package DBD::cubrid::dr; # ====== DRIVER ======
     use strict;
+
     
     sub connect {
 
@@ -186,6 +192,7 @@ use strict;
     use strict;
     use DBI qw(:sql_types);
 
+
     sub prepare {
 
         my ($dbh, $statement, @attribs) = @_;
@@ -681,7 +688,6 @@ DBD::cubrid - CUBRID driver for the Perl5 Database Interface (DBI)
     use DBI;
 
     $dsn = "DBI:cubrid:database=$database;host=$hostname;port=$port";
-    $dsn = "DBI:cubrid:database=$database;host=$hostname;port=$port;autocommit=$autocommit";
 
     $dbh = DBI->connect ($dsn, $user, $password);
     $sth = $dbh->prepare("SELECT * FROM TABLE");
@@ -752,7 +758,6 @@ consult the B<DBI> documentation first!
     $dsn = "DBI:cubrid:database=$database";
     $dsn = "DBI:cubrid:database=$database;host=$hostname";
     $dsn = "DBI:cubrid:database=$database;host=$hostname;port=$port";
-    $dsn = "DBI:cubrid:database=$database;host=$hostname;port=$port;autocommit=$autocommit"
 
     $dbh = DBI->connect ($dsn, $user, $password);
 
@@ -776,10 +781,6 @@ specified by althosts (failover), terminates the transaction, and then attempts
 connect to he active broker of the master database at every rctime. The default value
 is 600 seconds.
 
-B<autocommit> : String. Configures the auto-commit mode. The value maybe true, on, yes,
-false, off and no. You can set autocommit property here or in the C<\%attr> parameter.
-If you set this property at both places, the latter is effective.
-
 B<login_timeout> : INT. Configures the login timeout of CUBRID.
 
 B<query_timeout>: INT. Configures the query timeout of CUBRID.
@@ -804,6 +805,11 @@ The following are some examples about different $dsn:
 
     $query = 600;
     $dsn = "dbi:cubrid:database=$db;host=$host;port=$port;query_timeout=$query;disconnect_on_query_timeout=yes";
+    
+ B<Tips:  the autocommit has been removed from the dsn since RB-8.4.4. If you wanna set up the autocommit of the connection, you have to do:>
+
+    $dbh= DBI->connect ($dsn, $user, $password,
+                      { RaiseError => 1, PrintError => 1, AutoCommit => 0 });
 
 =head1 DBI Database Handle Object
 
@@ -1129,7 +1135,8 @@ Allows the user to bind a value and/or a data type to a placeholder. The value o
 is a number of using the '?' style placeholder. Generally, you can bind params without specifying
 the data type. CUBRID will match it automatically. That means, you don't use C<$bind_type> for
 most data types in CUBRID. But it won't work well with some special data types, such as BLOB and
-CLOB. The following are data types supported by CUBRID.
+CLOB. The following are data types supported by CUBRID.In CUBRID shard envrioment, the $bind_type 
+must be included in the bind_param function.
 
     -----------------------------------------
     | CUBRID        | sql_types             |
@@ -1199,6 +1206,15 @@ Examples of use:
     ok $sth->bind_param_array (1, ['aaa', 'bbb']);
     ok $sth->execute_array( { ArrayTupleStatus => \my @tuple_status } );
     
+=head3 B<execute>
+
+    $rv = $sth->execute;
+    $rv = $sth->execute (@bind_values);
+
+Executes a previously prepared statement. In addition to UPDATE, DELETE, INSERT 
+statements, for which it returns always the number of affected rows and to SELECT
+statements, it returns the number of rows thart will be returned by the query.
+
 =head3 B<execute_array>  
   
 Execute a prepared statement once for each item in a passed-in hashref, or items that were 
@@ -1224,15 +1240,6 @@ Examples of use:
     my @tuple_status;
     ok $sth->execute_array( { ArrayTupleStatus => \my @tuple_status } , [2,3,4,9]);
         
-=head3 B<execute>
-
-    $rv = $sth->execute;
-    $rv = $sth->execute (@bind_values);
-
-Executes a previously prepared statement. In addition to UPDATE, DELETE, INSERT 
-statements, for which it returns always the number of affected rows and to SELECT
-statements, it returns the number of rows thart will be returned by the query.
-
 =head3 B<fetchrow_arrayref>
 
     $ary_ref = $sth->fetchrow_arrayref;
